@@ -7,7 +7,7 @@
 #             ANY CHANGE MADE HERE WILL BE LOST !
 #
 ####################################################################
-package XDR::Parse;
+package XDR::Parse v0.1.1;
 use vars qw ( @ISA );
 use strict;
 
@@ -29,106 +29,106 @@ sub new {
 [
 	{#State 0
 		ACTIONS => {
-			'PASSTHROUGH' => 10,
-			"const" => 12,
-			'PREPROC' => 8,
-			"struct" => 4,
-			"union" => 6,
-			"enum" => 5,
-			"typedef" => 1
+			"struct" => 1,
+			"union" => 9,
+			'PREPROC' => 2,
+			"enum" => 11,
+			'PASSTHROUGH' => 4,
+			"const" => 6,
+			"typedef" => 7
 		},
 		GOTOS => {
-			'definitions' => 7,
-			'specification' => 3,
-			'typeDef' => 2,
-			'constantDef' => 11,
-			'definition' => 9
+			'typeDef' => 3,
+			'specification' => 12,
+			'definitions' => 8,
+			'constantDef' => 10,
+			'definition' => 5
 		}
 	},
 	{#State 1
 		ACTIONS => {
-			"string" => 24,
-			"void" => 25,
-			"short" => 27,
-			"float" => 26,
-			"quadruple" => 23,
-			"char" => 31,
-			"union" => 28,
-			"hyper" => 29,
-			"long" => 17,
-			"bool" => 16,
-			"unsigned" => 18,
-			'IDENT' => 15,
-			"int" => 14,
-			"enum" => 13,
-			"opaque" => 22,
-			"struct" => 20,
-			"double" => 21
-		},
-		GOTOS => {
-			'typeSpecifier' => 30,
-			'declaration' => 19
+			'IDENT' => 13
 		}
 	},
 	{#State 2
-		DEFAULT => -7
+		DEFAULT => -6
 	},
 	{#State 3
-		ACTIONS => {
-			'' => 32
-		}
+		DEFAULT => -7
 	},
 	{#State 4
-		ACTIONS => {
-			'IDENT' => 33
-		}
+		DEFAULT => -5
 	},
 	{#State 5
 		ACTIONS => {
-			'IDENT' => 34
+			"enum" => 11,
+			'PASSTHROUGH' => 4,
+			'PREPROC' => 2,
+			"struct" => 1,
+			"union" => 9,
+			"typedef" => 7,
+			"const" => 6
+		},
+		DEFAULT => -3,
+		GOTOS => {
+			'definition' => 5,
+			'typeDef' => 3,
+			'constantDef' => 10,
+			'definitions' => 14
 		}
 	},
 	{#State 6
 		ACTIONS => {
-			'IDENT' => 35
+			'IDENT' => 15
 		}
 	},
 	{#State 7
 		ACTIONS => {
-			'TRAILING_COMMENT' => 36
+			"char" => 18,
+			"struct" => 20,
+			"quadruple" => 19,
+			'IDENT' => 17,
+			"enum" => 29,
+			"long" => 27,
+			"short" => 34,
+			"union" => 33,
+			"double" => 32,
+			"float" => 30,
+			"hyper" => 31,
+			"string" => 21,
+			"int" => 25,
+			"unsigned" => 26,
+			"bool" => 24,
+			"opaque" => 23,
+			"void" => 22
+		},
+		GOTOS => {
+			'typeSpecifier' => 28,
+			'declaration' => 16
+		}
+	},
+	{#State 8
+		ACTIONS => {
+			'TRAILING_COMMENT' => 35
 		},
 		DEFAULT => -1
 	},
-	{#State 8
-		DEFAULT => -6
-	},
 	{#State 9
 		ACTIONS => {
-			'PREPROC' => 8,
-			'PASSTHROUGH' => 10,
-			"typedef" => 1,
-			"union" => 6,
-			"struct" => 4,
-			"const" => 12,
-			"enum" => 5
-		},
-		DEFAULT => -3,
-		GOTOS => {
-			'definition' => 9,
-			'definitions' => 37,
-			'constantDef' => 11,
-			'typeDef' => 2
+			'IDENT' => 36
 		}
 	},
 	{#State 10
-		DEFAULT => -5
+		DEFAULT => -8
 	},
 	{#State 11
-		DEFAULT => -8
+		ACTIONS => {
+			'IDENT' => 37
+		}
 	},
 	{#State 12
 		ACTIONS => {
-			'IDENT' => 38
+			'' => 38
 		}
 	},
 	{#State 13
@@ -136,306 +136,304 @@ sub new {
 			"{" => 40
 		},
 		GOTOS => {
-			'enumBody' => 39
+			'structBody' => 39
 		}
 	},
 	{#State 14
-		DEFAULT => -30
+		DEFAULT => -4
 	},
 	{#State 15
-		DEFAULT => -47
+		ACTIONS => {
+			"=" => 41
+		}
 	},
 	{#State 16
-		DEFAULT => -43
+		ACTIONS => {
+			";" => 42
+		}
 	},
 	{#State 17
-		DEFAULT => -36
+		DEFAULT => -47
 	},
 	{#State 18
-		ACTIONS => {
-			"int" => 41,
-			"hyper" => 44,
-			"char" => 45,
-			"short" => 43,
-			"long" => 42
-		}
-	},
-	{#State 19
-		ACTIONS => {
-			";" => 46
-		}
-	},
-	{#State 20
-		ACTIONS => {
-			"{" => 47
-		},
-		GOTOS => {
-			'structBody' => 48
-		}
-	},
-	{#State 21
-		DEFAULT => -41
-	},
-	{#State 22
-		ACTIONS => {
-			'IDENT' => 49
-		}
-	},
-	{#State 23
-		DEFAULT => -42
-	},
-	{#State 24
-		ACTIONS => {
-			'IDENT' => 50
-		}
-	},
-	{#State 25
-		DEFAULT => -60
-	},
-	{#State 26
-		DEFAULT => -40
-	},
-	{#State 27
-		DEFAULT => -34
-	},
-	{#State 28
-		ACTIONS => {
-			"switch" => 51
-		},
-		GOTOS => {
-			'switch' => 52
-		}
-	},
-	{#State 29
-		DEFAULT => -38
-	},
-	{#State 30
-		ACTIONS => {
-			'IDENT' => 54,
-			"*" => 53
-		}
-	},
-	{#State 31
 		DEFAULT => -32
 	},
-	{#State 32
-		DEFAULT => 0
+	{#State 19
+		DEFAULT => -42
 	},
-	{#State 33
-		ACTIONS => {
-			"{" => 47
-		},
-		GOTOS => {
-			'structBody' => 55
-		}
-	},
-	{#State 34
+	{#State 20
 		ACTIONS => {
 			"{" => 40
 		},
 		GOTOS => {
-			'enumBody' => 56
+			'structBody' => 43
 		}
 	},
-	{#State 35
+	{#State 21
 		ACTIONS => {
-			"switch" => 51
+			'IDENT' => 44
+		}
+	},
+	{#State 22
+		DEFAULT => -60
+	},
+	{#State 23
+		ACTIONS => {
+			'IDENT' => 45
+		}
+	},
+	{#State 24
+		DEFAULT => -43
+	},
+	{#State 25
+		DEFAULT => -30
+	},
+	{#State 26
+		ACTIONS => {
+			"hyper" => 48,
+			"int" => 50,
+			"short" => 47,
+			"char" => 46,
+			"long" => 49
+		}
+	},
+	{#State 27
+		DEFAULT => -36
+	},
+	{#State 28
+		ACTIONS => {
+			'IDENT' => 51,
+			"*" => 52
+		}
+	},
+	{#State 29
+		ACTIONS => {
+			"{" => 53
+		},
+		GOTOS => {
+			'enumBody' => 54
+		}
+	},
+	{#State 30
+		DEFAULT => -40
+	},
+	{#State 31
+		DEFAULT => -38
+	},
+	{#State 32
+		DEFAULT => -41
+	},
+	{#State 33
+		ACTIONS => {
+			"switch" => 56
+		},
+		GOTOS => {
+			'switch' => 55
+		}
+	},
+	{#State 34
+		DEFAULT => -34
+	},
+	{#State 35
+		DEFAULT => -2
+	},
+	{#State 36
+		ACTIONS => {
+			"switch" => 56
 		},
 		GOTOS => {
 			'switch' => 57
 		}
 	},
-	{#State 36
-		DEFAULT => -2
-	},
 	{#State 37
-		DEFAULT => -4
-	},
-	{#State 38
 		ACTIONS => {
-			"=" => 58
+			"{" => 53
+		},
+		GOTOS => {
+			'enumBody' => 58
 		}
 	},
+	{#State 38
+		DEFAULT => 0
+	},
 	{#State 39
-		DEFAULT => -44
+		ACTIONS => {
+			";" => 59
+		}
 	},
 	{#State 40
 		ACTIONS => {
-			'IDENT' => 61
+			"enum" => 29,
+			"long" => 27,
+			"short" => 34,
+			"double" => 32,
+			"union" => 33,
+			"hyper" => 31,
+			"float" => 30,
+			"string" => 21,
+			"bool" => 24,
+			"unsigned" => 26,
+			"int" => 25,
+			"void" => 22,
+			"opaque" => 23,
+			"char" => 18,
+			"struct" => 20,
+			"quadruple" => 19,
+			'IDENT' => 17
 		},
 		GOTOS => {
-			'enumItems' => 59,
-			'enumItem' => 60
+			'structItem' => 62,
+			'structItems' => 61,
+			'declaration' => 60,
+			'typeSpecifier' => 28
 		}
 	},
 	{#State 41
-		DEFAULT => -31
+		ACTIONS => {
+			'CONST' => 63,
+			'IDENT' => 64
+		}
 	},
 	{#State 42
-		DEFAULT => -37
-	},
-	{#State 43
-		DEFAULT => -35
-	},
-	{#State 44
-		DEFAULT => -39
-	},
-	{#State 45
-		DEFAULT => -33
-	},
-	{#State 46
 		DEFAULT => -9
 	},
-	{#State 47
-		ACTIONS => {
-			"quadruple" => 23,
-			"string" => 24,
-			"short" => 27,
-			"void" => 25,
-			"float" => 26,
-			"union" => 28,
-			"hyper" => 29,
-			"char" => 31,
-			"enum" => 13,
-			"int" => 14,
-			'IDENT' => 15,
-			"bool" => 16,
-			"unsigned" => 18,
-			"long" => 17,
-			"struct" => 20,
-			"double" => 21,
-			"opaque" => 22
-		},
-		GOTOS => {
-			'declaration' => 64,
-			'structItem' => 62,
-			'structItems' => 63,
-			'typeSpecifier' => 30
-		}
-	},
-	{#State 48
+	{#State 43
 		DEFAULT => -45
 	},
-	{#State 49
+	{#State 44
 		ACTIONS => {
-			"[" => 65,
-			"<" => 66
+			"<" => 65
 		}
 	},
-	{#State 50
+	{#State 45
 		ACTIONS => {
-			"<" => 67
+			"<" => 66,
+			"[" => 67
 		}
 	},
+	{#State 46
+		DEFAULT => -33
+	},
+	{#State 47
+		DEFAULT => -35
+	},
+	{#State 48
+		DEFAULT => -39
+	},
+	{#State 49
+		DEFAULT => -37
+	},
+	{#State 50
+		DEFAULT => -31
+	},
 	{#State 51
 		ACTIONS => {
-			"(" => 68
-		}
-	},
-	{#State 52
-		DEFAULT => -46
-	},
-	{#State 53
-		ACTIONS => {
-			'IDENT' => 69
-		}
-	},
-	{#State 54
-		ACTIONS => {
-			"<" => 71,
-			"[" => 70
+			"[" => 68,
+			"<" => 69
 		},
 		DEFAULT => -50
 	},
-	{#State 55
+	{#State 52
 		ACTIONS => {
-			";" => 72
+			'IDENT' => 70
 		}
 	},
+	{#State 53
+		ACTIONS => {
+			'IDENT' => 72
+		},
+		GOTOS => {
+			'enumItem' => 73,
+			'enumItems' => 71
+		}
+	},
+	{#State 54
+		DEFAULT => -44
+	},
+	{#State 55
+		DEFAULT => -46
+	},
 	{#State 56
 		ACTIONS => {
-			";" => 73
+			"(" => 74
 		}
 	},
 	{#State 57
 		ACTIONS => {
-			";" => 74
+			";" => 75
 		}
 	},
 	{#State 58
 		ACTIONS => {
-			'IDENT' => 75,
-			'CONST' => 76
+			";" => 76
 		}
 	},
 	{#State 59
-		ACTIONS => {
-			"}" => 77
-		}
+		DEFAULT => -11
 	},
 	{#State 60
 		ACTIONS => {
-			"," => 78
-		},
-		DEFAULT => -27
+			";" => 77
+		}
 	},
 	{#State 61
 		ACTIONS => {
-			"=" => 79
+			"}" => 78
 		}
 	},
 	{#State 62
 		ACTIONS => {
-			"short" => 27,
-			"void" => 25,
-			"float" => 26,
-			"string" => 24,
-			"quadruple" => 23,
-			"char" => 31,
-			"hyper" => 29,
-			"union" => 28,
-			"bool" => 16,
-			"unsigned" => 18,
-			"long" => 17,
-			"enum" => 13,
-			'IDENT' => 15,
-			"int" => 14,
-			"opaque" => 22,
-			"double" => 21,
-			"struct" => 20
+			"float" => 30,
+			"hyper" => 31,
+			"union" => 33,
+			"double" => 32,
+			"short" => 34,
+			"long" => 27,
+			"enum" => 29,
+			"void" => 22,
+			"opaque" => 23,
+			"unsigned" => 26,
+			"bool" => 24,
+			"int" => 25,
+			"string" => 21,
+			"quadruple" => 19,
+			"struct" => 20,
+			"char" => 18,
+			'IDENT' => 17
 		},
 		DEFAULT => -23,
 		GOTOS => {
-			'declaration' => 64,
-			'structItem' => 62,
-			'typeSpecifier' => 30,
-			'structItems' => 80
+			'declaration' => 60,
+			'structItems' => 79,
+			'typeSpecifier' => 28,
+			'structItem' => 62
 		}
 	},
 	{#State 63
 		ACTIONS => {
-			"}" => 81
+			";" => 80
 		}
 	},
 	{#State 64
 		ACTIONS => {
-			";" => 82
+			";" => 81
 		}
 	},
 	{#State 65
 		ACTIONS => {
+			">" => 85,
 			'CONST' => 84,
 			'IDENT' => 83
 		},
 		GOTOS => {
-			'value' => 85
+			'value' => 82
 		}
 	},
 	{#State 66
 		ACTIONS => {
-			'IDENT' => 83,
 			">" => 86,
-			'CONST' => 84
+			'CONST' => 84,
+			'IDENT' => 83
 		},
 		GOTOS => {
 			'value' => 87
@@ -444,108 +442,100 @@ sub new {
 	{#State 67
 		ACTIONS => {
 			'CONST' => 84,
-			">" => 88,
 			'IDENT' => 83
 		},
+		GOTOS => {
+			'value' => 88
+		}
+	},
+	{#State 68
+		ACTIONS => {
+			'IDENT' => 83,
+			'CONST' => 84
+		},
 		GOTOS => {
 			'value' => 89
 		}
 	},
-	{#State 68
-		ACTIONS => {
-			"double" => 21,
-			"struct" => 20,
-			"opaque" => 22,
-			"enum" => 13,
-			"int" => 14,
-			'IDENT' => 15,
-			"bool" => 16,
-			"long" => 17,
-			"unsigned" => 18,
-			"hyper" => 29,
-			"union" => 28,
-			"char" => 31,
-			"quadruple" => 23,
-			"short" => 27,
-			"float" => 26,
-			"void" => 25,
-			"string" => 24
-		},
-		GOTOS => {
-			'declaration' => 90,
-			'typeSpecifier' => 30
-		}
-	},
 	{#State 69
-		DEFAULT => -59
-	},
-	{#State 70
 		ACTIONS => {
-			'IDENT' => 83,
-			'CONST' => 84
+			'CONST' => 84,
+			">" => 90,
+			'IDENT' => 83
 		},
 		GOTOS => {
 			'value' => 91
 		}
 	},
+	{#State 70
+		DEFAULT => -59
+	},
 	{#State 71
 		ACTIONS => {
-			'CONST' => 84,
-			'IDENT' => 83,
-			">" => 92
-		},
-		GOTOS => {
-			'value' => 93
+			"}" => 92
 		}
 	},
 	{#State 72
-		DEFAULT => -11
+		ACTIONS => {
+			"=" => 93
+		}
 	},
 	{#State 73
-		DEFAULT => -10
+		ACTIONS => {
+			"," => 94
+		},
+		DEFAULT => -27
 	},
 	{#State 74
-		DEFAULT => -12
+		ACTIONS => {
+			"string" => 21,
+			"int" => 25,
+			"bool" => 24,
+			"unsigned" => 26,
+			"opaque" => 23,
+			"void" => 22,
+			"enum" => 29,
+			"long" => 27,
+			"short" => 34,
+			"hyper" => 31,
+			"float" => 30,
+			"double" => 32,
+			"union" => 33,
+			'IDENT' => 17,
+			"char" => 18,
+			"quadruple" => 19,
+			"struct" => 20
+		},
+		GOTOS => {
+			'declaration' => 95,
+			'typeSpecifier' => 28
+		}
 	},
 	{#State 75
-		ACTIONS => {
-			";" => 94
-		}
+		DEFAULT => -12
 	},
 	{#State 76
-		ACTIONS => {
-			";" => 95
-		}
+		DEFAULT => -10
 	},
 	{#State 77
-		DEFAULT => -26
+		DEFAULT => -25
 	},
 	{#State 78
-		ACTIONS => {
-			'IDENT' => 61
-		},
-		GOTOS => {
-			'enumItems' => 96,
-			'enumItem' => 60
-		}
-	},
-	{#State 79
-		ACTIONS => {
-			'IDENT' => 83,
-			'CONST' => 84
-		},
-		GOTOS => {
-			'value' => 97
-		}
-	},
-	{#State 80
-		DEFAULT => -24
-	},
-	{#State 81
 		DEFAULT => -22
 	},
+	{#State 79
+		DEFAULT => -24
+	},
+	{#State 80
+		DEFAULT => -13
+	},
+	{#State 81
+		DEFAULT => -14
+	},
 	{#State 82
-		DEFAULT => -25
+		ACTIONS => {
+			">" => 96
+		}
 	},
 	{#State 83
 		DEFAULT => -49
@@ -554,121 +544,131 @@ sub new {
 		DEFAULT => -48
 	},
 	{#State 85
-		ACTIONS => {
-			"]" => 98
-		}
+		DEFAULT => -57
 	},
 	{#State 86
 		DEFAULT => -55
 	},
 	{#State 87
 		ACTIONS => {
-			">" => 99
+			">" => 97
 		}
 	},
 	{#State 88
-		DEFAULT => -57
+		ACTIONS => {
+			"]" => 98
+		}
 	},
 	{#State 89
+		ACTIONS => {
+			"]" => 99
+		}
+	},
+	{#State 90
+		DEFAULT => -52
+	},
+	{#State 91
 		ACTIONS => {
 			">" => 100
 		}
 	},
-	{#State 90
-		ACTIONS => {
-			")" => 101
-		}
-	},
-	{#State 91
-		ACTIONS => {
-			"]" => 102
-		}
-	},
 	{#State 92
-		DEFAULT => -52
+		DEFAULT => -26
 	},
 	{#State 93
-		ACTIONS => {
-			">" => 103
-		}
-	},
-	{#State 94
-		DEFAULT => -14
-	},
-	{#State 95
-		DEFAULT => -13
-	},
-	{#State 96
-		DEFAULT => -28
-	},
-	{#State 97
-		DEFAULT => -29
-	},
-	{#State 98
-		DEFAULT => -54
-	},
-	{#State 99
-		DEFAULT => -56
-	},
-	{#State 100
-		DEFAULT => -58
-	},
-	{#State 101
-		ACTIONS => {
-			"{" => 104
-		}
-	},
-	{#State 102
-		DEFAULT => -51
-	},
-	{#State 103
-		DEFAULT => -53
-	},
-	{#State 104
-		ACTIONS => {
-			"case" => 106
-		},
-		GOTOS => {
-			'caseClauses' => 107,
-			'caseClause' => 108,
-			'caseBody' => 105
-		}
-	},
-	{#State 105
-		ACTIONS => {
-			"}" => 109
-		}
-	},
-	{#State 106
 		ACTIONS => {
 			'CONST' => 84,
 			'IDENT' => 83
 		},
 		GOTOS => {
-			'value' => 110
+			'value' => 101
+		}
+	},
+	{#State 94
+		ACTIONS => {
+			'IDENT' => 72
+		},
+		GOTOS => {
+			'enumItem' => 73,
+			'enumItems' => 102
+		}
+	},
+	{#State 95
+		ACTIONS => {
+			")" => 103
+		}
+	},
+	{#State 96
+		DEFAULT => -58
+	},
+	{#State 97
+		DEFAULT => -56
+	},
+	{#State 98
+		DEFAULT => -54
+	},
+	{#State 99
+		DEFAULT => -51
+	},
+	{#State 100
+		DEFAULT => -53
+	},
+	{#State 101
+		DEFAULT => -29
+	},
+	{#State 102
+		DEFAULT => -28
+	},
+	{#State 103
+		ACTIONS => {
+			"{" => 104
+		}
+	},
+	{#State 104
+		ACTIONS => {
+			"case" => 107
+		},
+		GOTOS => {
+			'caseClause' => 105,
+			'caseClauses' => 106,
+			'caseBody' => 108
+		}
+	},
+	{#State 105
+		ACTIONS => {
+			"case" => 107
+		},
+		DEFAULT => -18,
+		GOTOS => {
+			'caseClauses' => 109,
+			'caseClause' => 105
+		}
+	},
+	{#State 106
+		ACTIONS => {
+			"default" => 110
+		},
+		DEFAULT => -16,
+		GOTOS => {
+			'defaultClause' => 111
 		}
 	},
 	{#State 107
 		ACTIONS => {
-			"default" => 111
+			'CONST' => 84,
+			'IDENT' => 83
 		},
-		DEFAULT => -16,
 		GOTOS => {
-			'defaultClause' => 112
+			'value' => 112
 		}
 	},
 	{#State 108
 		ACTIONS => {
-			"case" => 106
-		},
-		DEFAULT => -18,
-		GOTOS => {
-			'caseClause' => 108,
-			'caseClauses' => 113
+			"}" => 113
 		}
 	},
 	{#State 109
-		DEFAULT => -15
+		DEFAULT => -19
 	},
 	{#State 110
 		ACTIONS => {
@@ -676,64 +676,64 @@ sub new {
 		}
 	},
 	{#State 111
+		DEFAULT => -17
+	},
+	{#State 112
 		ACTIONS => {
 			":" => 115
 		}
 	},
-	{#State 112
-		DEFAULT => -17
-	},
 	{#State 113
-		DEFAULT => -19
+		DEFAULT => -15
 	},
 	{#State 114
 		ACTIONS => {
-			"quadruple" => 23,
-			"float" => 26,
-			"void" => 25,
-			"short" => 27,
-			"string" => 24,
-			"hyper" => 29,
-			"union" => 28,
-			"char" => 31,
-			'IDENT' => 15,
-			"int" => 14,
-			"enum" => 13,
-			"long" => 17,
-			"bool" => 16,
-			"unsigned" => 18,
-			"double" => 21,
+			"char" => 18,
 			"struct" => 20,
-			"opaque" => 22
+			"quadruple" => 19,
+			'IDENT' => 17,
+			"enum" => 29,
+			"long" => 27,
+			"short" => 34,
+			"union" => 33,
+			"double" => 32,
+			"hyper" => 31,
+			"float" => 30,
+			"string" => 21,
+			"int" => 25,
+			"unsigned" => 26,
+			"bool" => 24,
+			"void" => 22,
+			"opaque" => 23
 		},
 		GOTOS => {
-			'typeSpecifier' => 30,
+			'typeSpecifier' => 28,
 			'declaration' => 116
 		}
 	},
 	{#State 115
 		ACTIONS => {
-			"int" => 14,
-			'IDENT' => 15,
-			"enum" => 13,
-			"long" => 17,
-			"bool" => 16,
-			"unsigned" => 18,
-			"double" => 21,
+			"long" => 27,
+			"enum" => 29,
+			"float" => 30,
+			"hyper" => 31,
+			"union" => 33,
+			"double" => 32,
+			"short" => 34,
+			"string" => 21,
+			"void" => 22,
+			"opaque" => 23,
+			"int" => 25,
+			"unsigned" => 26,
+			"bool" => 24,
+			"char" => 18,
+			"quadruple" => 19,
 			"struct" => 20,
-			"opaque" => 22,
-			"quadruple" => 23,
-			"void" => 25,
-			"float" => 26,
-			"short" => 27,
-			"string" => 24,
-			"hyper" => 29,
-			"union" => 28,
-			"char" => 31
+			'IDENT' => 17
 		},
 		GOTOS => {
-			'typeSpecifier' => 30,
-			'declaration' => 117
+			'declaration' => 117,
+			'typeSpecifier' => 28
 		}
 	},
 	{#State 116
@@ -747,10 +747,10 @@ sub new {
 		}
 	},
 	{#State 118
-		DEFAULT => -20
+		DEFAULT => -21
 	},
 	{#State 119
-		DEFAULT => -21
+		DEFAULT => -20
 	}
 ],
                                   yyrules  =>
@@ -1375,6 +1375,10 @@ sub parse {
 
 XDR::Parse - Creation of an AST of an XDR specification
 
+=head1 VERSION
+
+0.1.1
+
 =head1 SYNOPSIS
 
   use XDR::Parse;
